:mod:`oasis.stratification`.Strata
=========================================

.. currentmodule:: oasis.stratification

.. autoclass:: Strata

   
   .. automethod:: __init__
   

.. Not needed since there is no "Examples" section in the docstrings
.. .. include:: oasis.stratification.Strata.examples

.. raw:: html

    <div class="clearer"></div>